@@ -1,5 +1,5 @@
 package Net::Whois::Raw;
-$Net::Whois::Raw::VERSION = '2.99019';
+$Net::Whois::Raw::VERSION = '2.99020';
 # ABSTRACT: Get Whois information of domains and IP addresses.
 
 require 5.008_001;
@@ -176,7 +176,7 @@ sub recursive_whois {
         $registrar ||= /Registrar/ || /Registered through/;
 
         # Skip urls as recursive whois servers
-        if ( $registrar && !$norecurse && /whois server:\s*([a-z0-9\-_\.]+)$/i ) {
+        if ( $registrar && !$norecurse && /whois server:\s*([a-z0-9\-_\.]+)\b/i ) {
             $newsrv = lc $1;
         }
         elsif ( $whois =~ /To single out one record, look it up with \"xxx\",/s ) {
@@ -479,7 +479,7 @@ Net::Whois::Raw - Get Whois information of domains and IP addresses.
 
 =head1 VERSION
 
-version 2.99019
+version 2.99020
 
 =head1 SYNOPSIS
 
